@@ -4,12 +4,10 @@ import math
 import plotly.express as px
 import seaborn as sns
 from matplotlib import pyplot as plt
-import hvplot.pandas
+
 
 def andrewscurves(data, class_column, samples):
     """
-    
-
     Parameters
     ----------
     data : pandas.DataFrame
@@ -45,8 +43,6 @@ def andrewscurves(data, class_column, samples):
     return df
 def plotly_andrews_curves(data, class_column, samples):
     """
-    
-
     Parameters
     ----------
     data : pandas.DataFrame
@@ -67,8 +63,6 @@ def plotly_andrews_curves(data, class_column, samples):
     return fig
 def seaborn_andrews_curves(data, class_column, samples):
     """
-    
-
     Parameters
     ----------
     data : pandas.DataFrame
@@ -85,6 +79,7 @@ def seaborn_andrews_curves(data, class_column, samples):
 
     """
     df = andrewscurves(data, class_column, samples)
+    df = df.reset_index(drop=True)
     sns.set_theme(style = "darkgrid")
     plt.figure(figsize=(15,8))
     fig = sns.lineplot(x = 't', y = 'f(t)', hue = class_column,
@@ -92,8 +87,6 @@ def seaborn_andrews_curves(data, class_column, samples):
     return fig
 def mpl_andrews_curves(data, class_column, samples):
     """
-    
-
     Parameters
     ----------
     data : pandas.DataFrame
@@ -112,8 +105,6 @@ def mpl_andrews_curves(data, class_column, samples):
     return pd.plotting.andrews_curves(data, class_column, samples = samples)
 def hvplot_andrews_curves(data, class_column, samples):
     """
-    
-
     Parameters
     ----------
     data : pandas.DataFrame
@@ -129,6 +120,9 @@ def hvplot_andrews_curves(data, class_column, samples):
         output an interactive holoviews chart
 
     """
+    import holoviews as hv
+    hv.extension('bokeh')
+    import hvplot.pandas
     return hvplot.andrews_curves(data, class_column, samples = samples)
 
     
